# ReplicationJob

The three-step process by which Stitch replicates data. A replication job includes three distinct steps: Extraction, preparation, and loading.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**job_name** | **str** | A unique identifier for the replication job. | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


